==> truv_flutter-0.1.0.tar.gz: lib/truv_flutter.dart <==
library truv_flutter;

import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'package:url_launcher/url_launcher.dart';

typedef OnEventCallback = void Function(String event);

const truvDomain = 'https://cdn.truv.com';

class TruvBridge extends StatefulWidget {
  final OnEventCallback onEvent;
  final String bridgeToken;

  const TruvBridge(
      {Key? key,
      required this.onEvent,
      required this.bridgeToken})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _TruvBridgeState();
  }
}

class _TruvBridgeState extends State<TruvBridge>
    with AutomaticKeepAliveClientMixin {
  _TruvBridgeState();
  final Completer<WebViewController> _controller =
      Completer<WebViewController>();

  JavascriptChannel jsChannel(BuildContext context) {
    return JavascriptChannel(
        name: 'ReactNativeWebView',
        onMessageReceived: (JavascriptMessage message) {
          widget.onEvent(message.message);
        });
  }

  @override
  void didUpdateWidget(TruvBridge oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.bridgeToken != widget.bridgeToken &&
        widget.bridgeToken != '') {
      updateWebviewUrl();
    }
  }

  @override
  void initState() {
    updateWebviewUrl();
    super.initState();
  }

  void updateWebviewUrl() {
    _controller.future.then((WebViewController controller) {
      controller.loadUrl(
          '$truvDomain/mobile.html?bridge_token=${widget.bridgeToken}');
    });
  }

  @override
  bool get wantKeepAlive => true;

  @override
  Widget build(BuildContext context) {
    super.build(context);
    return WebView(
      onWebViewCreated: (WebViewController webViewController) {
        _controller.complete(webViewController);
      },
      javascriptChannels: <JavascriptChannel>{jsChannel(context)},
      javascriptMode: JavascriptMode.unrestricted,
      gestureRecognizers: {Factory(() => EagerGestureRecognizer())},
      navigationDelegate: (NavigationRequest request) {
        if (request.url.contains(truvDomain)) {
          return NavigationDecision.navigate;
        }

        final url = Uri.tryParse(request.url);
        if (url == null) {
          return NavigationDecision.prevent;
        }

        _launchURL(url);

        return NavigationDecision.prevent;
      },
    );
  }

  _launchURL(Uri url) async {
    if (await canLaunchUrl(url)) {
      await launchUrl(url);
    }
  }
}

==> truv_flutter-0.4.0.tar.gz: lib/truv_flutter.dart <==
library truv_flutter;

import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'package:url_launcher/url_launcher.dart';

typedef OnEventCallback = void Function(String event);

final truvUri = Uri.parse('https://cdn.truv.com/mobile.html');

class TruvBridge extends StatefulWidget {
  final OnEventCallback onEvent;
  final String bridgeToken;
  final Uri? truvUriOveride;
  final bool debug;

  const TruvBridge({
    Key? key,
    required this.onEvent,
    required this.bridgeToken,
    this.truvUriOveride,
    this.debug = false,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _TruvBridgeState();
  }
}

class _TruvBridgeState extends State<TruvBridge>
    with AutomaticKeepAliveClientMixin {
  _TruvBridgeState();
  final Completer<WebViewController> _controller =
      Completer<WebViewController>();

  JavascriptChannel jsChannel(BuildContext context) {
    return JavascriptChannel(
        name: 'ReactNativeWebView',
        onMessageReceived: (JavascriptMessage message) {
          widget.onEvent(message.message);
        });
  }

  @override
  void didUpdateWidget(TruvBridge oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.bridgeToken != widget.bridgeToken &&
        widget.bridgeToken != '') {
      updateWebviewUrl();
    }
  }

  @override
  void initState() {
    updateWebviewUrl();
    super.initState();
  }

  Uri get widgetUri => widget.truvUriOveride ?? truvUri;

  void updateWebviewUrl() {
    _controller.future.then((WebViewController controller) {
      controller.loadUrl(
          '${widgetUri.toString()}?bridge_token=${widget.bridgeToken}');
    });
  }

  @override
  bool get wantKeepAlive => true;

  @override
  Widget build(BuildContext context) {
    super.build(context);
    return WebView(
      onWebViewCreated: (WebViewController webViewController) {
        _controller.complete(webViewController);
      },
      javascriptChannels: <JavascriptChannel>{jsChannel(context)},
      javascriptMode: JavascriptMode.unrestricted,
      gestureRecognizers: {Factory(() => EagerGestureRecognizer())},
      debuggingEnabled: widget.debug,
      navigationDelegate: (NavigationRequest request) {
        if (request.url.contains(widgetUri.host)) {
          return NavigationDecision.navigate;
        }

        final url = Uri.tryParse(request.url);
        if (url == null) {
          return NavigationDecision.prevent;
        }

        _launchURL(url);

        return NavigationDecision.prevent;
      },
    );
  }

  _launchURL(Uri url) async {
    if (await canLaunchUrl(url)) {
      await launchUrl(url);
    }
  }
}
